@@ -7,9 +7,13 @@ OC.L10N.register(
     "Latest revision" : "Viimeisin versio",
     "More versions..." : "Lisää versioita...",
     "Just now" : "Juuri nyt",
+    "Failed to revert the document to older version" : "Asiakirjan palauttaminen aikaisempaan versioon epäonnistui",
     "Save" : "Tallenna",
     "Loading documents..." : "Ladataan asiakirjoja...",
     "Edit" : "Muokkaa",
+    "New Document" : "Uusi asiakirja",
+    "New Spreadsheet" : "Uusi taulukko",
+    "New Presentation" : "Uusi esitys",
     "Could not create file" : "Tiedoston luominen epäonnistui",
     "New Document.odt" : "Uusi asiakirja.odt",
     "New Spreadsheet.ods" : "Uusi taulukko.ods",
@@ -19,7 +23,12 @@ OC.L10N.register(
     "New Presentation.pptx" : "Uusi esitys.pptx",
     "Can't create document" : "Asiakirjan luominen epäonnistui",
     "Saved" : "Tallennettu",
+    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Tallennettu virheen kanssa: Collabora Onlinen tulee käyttää palvelimen kanssa samaa protokollaa.",
+    "Collabora Online" : "Collabora Online",
+    "Collabora Online server" : "Collabora Online -palvelin",
+    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL-osoite (ja portti) Collabora Online -palvelimelle, joka tarjoaa mukkaustoiminnot WOPI-asiakkaana.",
     "Apply" : "Toteuta",
+    "Use OOXML by default for new files" : "Käytä OOXML:ää oletuksena uusille tiedostoille",
     "Wrong password. Please retry." : "Väärä salasana. Yritä uudelleen.",
     "Password" : "Salasana",
     "OK" : "OK",
