@@ -116,6 +116,17 @@ class DocumentController extends Controller {
 				'instanceId' => $this->settings->getSystemValue('instanceid'),
 			];
 
+			$encryptionManager = \OC::$server->getEncryptionManager();
+			if ($encryptionManager->isEnabled())
+			{
+				// Update the current file to be accessible with system public shared key
+				$owner = $item->getOwner()->getUID();
+				$absPath = '/' . $owner . '/' .  $item->getInternalPath();
+				$accessList = \OC::$server->getEncryptionFilesHelper()->getAccessList($absPath);
+				$accessList['public'] = true;
+				$encryptionManager->getEncryptionModule()->update($absPath, $owner, $accessList);
+			}
+
 			$response = new TemplateResponse('richdocuments', 'documents', $params, 'empty');
 			$policy = new ContentSecurityPolicy();
 			$policy->addAllowedFrameDomain($this->appConfig->getAppValue('wopi_url'));
