@@ -120,7 +120,7 @@ class WopiController extends Controller {
 			/** @var File $file */
 			$userFolder = $this->rootFolder->getUserFolder($res['owner']);
 			$file = $userFolder->getById($fileId)[0];
-
+			\OC_User::setIncognitoMode(true);
 			if ($version !== '0')
 			{
 				$view = new View('/' . $res['owner'] . '/files');
@@ -177,6 +177,14 @@ class WopiController extends Controller {
 			// Setup the FS which is needed to emit hooks (versioning).
 			\OC_Util::tearDownFS();
 			\OC_Util::setupFS($res['owner']);
+
+			// Set the user to register the change under his name
+			$editor = \OC::$server->getUserManager()->get($res['editor']);
+			if (is_null($editor)) {
+				throw new \OC\User\NoUserException("User " . $res['editor'] . "not found.");
+			}
+			\OC::$server->getUserSession()->setUser($editor);
+
 			$file->putContent($content);
 			return new JSONResponse();
 		} catch (\Exception $e) {
